@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "20.0.1+9" },
-            { "jdk", "20.0.1" },
-            { "release", "20.0.1" },
+            { "full", "21.0.5+11-LTS" },
+            { "jdk", "21.0.5" },
+            { "release", "21.0.5" },
         };
     }
 }
